==> igniteui-react-core-18.1.0.tgz: package/esm2015/lib/WebColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnDescription = /*@__PURE__*/ (() => {
    class WebColumnDescription extends Description {
        constructor() {
            super();
            this.bt = null;
            this.bw = null;
            this.b5 = null;
            this.ac = false;
            this.aa = false;
            this.t = false;
            this.p = false;
            this.r = false;
            this.y = false;
            this.l = false;
            this.u = false;
            this.v = false;
            this.ab = false;
            this.n = false;
            this.o = false;
            this.w = false;
            this.b6 = null;
            this.a1 = 0;
            this.b1 = null;
            this.bx = null;
            this.bf = null;
            this.by = null;
            this.be = null;
            this.bo = null;
            this.bp = null;
            this.s = false;
            this.ad = false;
            this.z = false;
            this.bq = null;
            this.a5 = 0;
            this.a3 = 0;
            this.a6 = 0;
            this.a4 = 0;
            this.bd = null;
            this.a2 = 0;
            this.b2 = null;
            this.x = false;
            this.bh = null;
            this.h = null;
            this.j = null;
            this.b4 = null;
            this.bn = null;
            this.bz = null;
            this.b0 = null;
            this.bs = null;
            this.bu = null;
            this.ae = false;
            this.f = null;
            this.m = false;
            this.q = false;
            this.br = null;
            this.af = false;
            this.bg = null;
            this.bv = null;
            this.b3 = null;
        }
        get_type() {
            return "WebColumn";
        }
        get type() {
            return this.get_type();
        }
        get field() {
            return this.bt;
        }
        set field(a) {
            this.bt = a;
            this.e("Field");
        }
        get header() {
            return this.bw;
        }
        set header(a) {
            this.bw = a;
            this.e("Header");
        }
        get title() {
            return this.b5;
        }
        set title(a) {
            this.b5 = a;
            this.e("Title");
        }
        get sortable() {
            return this.ac;
        }
        set sortable(a) {
            this.ac = a;
            this.e("Sortable");
        }
        get selectable() {
            return this.aa;
        }
        set selectable(a) {
            this.aa = a;
            this.e("Selectable");
        }
        get groupable() {
            return this.t;
        }
        set groupable(a) {
            this.t = a;
            this.e("Groupable");
        }
        get editable() {
            return this.p;
        }
        set editable(a) {
            this.p = a;
            this.e("Editable");
        }
        get filterable() {
            return this.r;
        }
        set filterable(a) {
            this.r = a;
            this.e("Filterable");
        }
        get resizable() {
            return this.y;
        }
        set resizable(a) {
            this.y = a;
            this.e("Resizable");
        }
        get autosizeHeader() {
            return this.l;
        }
        set autosizeHeader(a) {
            this.l = a;
            this.e("AutosizeHeader");
        }
        get hasSummary() {
            return this.u;
        }
        set hasSummary(a) {
            this.u = a;
            this.e("HasSummary");
        }
        get hidden() {
            return this.v;
        }
        set hidden(a) {
            this.v = a;
            this.e("Hidden");
        }
        get selected() {
            return this.ab;
        }
        set selected(a) {
            this.ab = a;
            this.e("Selected");
        }
        get disableHiding() {
            return this.n;
        }
        set disableHiding(a) {
            this.n = a;
            this.e("DisableHiding");
        }
        get disablePinning() {
            return this.o;
        }
        set disablePinning(a) {
            this.o = a;
            this.e("DisablePinning");
        }
        get movable() {
            return this.w;
        }
        set movable(a) {
            this.w = a;
            this.e("Movable");
        }
        get width() {
            return this.b6;
        }
        set width(a) {
            this.b6 = a;
            this.e("Width");
        }
        get autoSize() {
            return this.a1;
        }
        set autoSize(a) {
            this.a1 = a;
            this.e("AutoSize");
        }
        get maxWidth() {
            return this.b1;
        }
        set maxWidth(a) {
            this.b1 = a;
            this.e("MaxWidth");
        }
        get headerClasses() {
            return this.bx;
        }
        set headerClasses(a) {
            this.bx = a;
            this.e("HeaderClasses");
        }
        get headerStyles() {
            return this.bf;
        }
        set headerStyles(a) {
            this.bf = a;
            this.e("HeaderStyles");
        }
        get headerGroupClasses() {
            return this.by;
        }
        set headerGroupClasses(a) {
            this.by = a;
            this.e("HeaderGroupClasses");
        }
        get headerGroupStyles() {
            return this.be;
        }
        set headerGroupStyles(a) {
            this.be = a;
            this.e("HeaderGroupStyles");
        }
        get cellClassesRef() {
            return this.bo;
        }
        set cellClassesRef(a) {
            this.bo = a;
            this.e("CellClassesRef");
        }
        get cellStylesRef() {
            return this.bp;
        }
        set cellStylesRef(a) {
            this.bp = a;
            this.e("CellStylesRef");
        }
        get filteringIgnoreCase() {
            return this.s;
        }
        set filteringIgnoreCase(a) {
            this.s = a;
            this.e("FilteringIgnoreCase");
        }
        get sortingIgnoreCase() {
            return this.ad;
        }
        set sortingIgnoreCase(a) {
            this.ad = a;
            this.e("SortingIgnoreCase");
        }
        get searchable() {
            return this.z;
        }
        set searchable(a) {
            this.z = a;
            this.e("Searchable");
        }
        get dataType() {
            return this.bq;
        }
        set dataType(a) {
            this.bq = a;
            this.e("DataType");
        }
        get rowEnd() {
            return this.a5;
        }
        set rowEnd(a) {
            this.a5 = a;
            this.e("RowEnd");
        }
        get colEnd() {
            return this.a3;
        }
        set colEnd(a) {
            this.a3 = a;
            this.e("ColEnd");
        }
        get rowStart() {
            return this.a6;
        }
        set rowStart(a) {
            this.a6 = a;
            this.e("RowStart");
        }
        get colStart() {
            return this.a4;
        }
        set colStart(a) {
            this.a4 = a;
            this.e("ColStart");
        }
        get additionalTemplateContext() {
            return this.bd;
        }
        set additionalTemplateContext(a) {
            this.bd = a;
            this.e("AdditionalTemplateContext");
        }
        get calcPixelWidth() {
            return this.a2;
        }
        set calcPixelWidth(a) {
            this.a2 = a;
            this.e("CalcPixelWidth");
        }
        get minWidth() {
            return this.b2;
        }
        set minWidth(a) {
            this.b2 = a;
            this.e("MinWidth");
        }
        get pinned() {
            return this.x;
        }
        set pinned(a) {
            this.x = a;
            this.e("Pinned");
        }
        get summaries() {
            return this.bh;
        }
        set summaries(a) {
            this.bh = a;
            this.e("Summaries");
        }
        get filters() {
            return this.h;
        }
        set filters(a) {
            this.h = a;
            this.e("Filters");
        }
        get sortStrategy() {
            return this.j;
        }
        set sortStrategy(a) {
            this.j = a;
            this.e("SortStrategy");
        }
        get summaryTemplateRef() {
            return this.b4;
        }
        set summaryTemplateRef(a) {
            this.b4 = a;
            this.e("SummaryTemplateRef");
        }
        get bodyTemplateRef() {
            return this.bn;
        }
        set bodyTemplateRef(a) {
            this.bn = a;
            this.e("BodyTemplateRef");
        }
        get headerTemplateRef() {
            return this.bz;
        }
        set headerTemplateRef(a) {
            this.bz = a;
            this.e("HeaderTemplateRef");
        }
        get inlineEditorTemplateRef() {
            return this.b0;
        }
        set inlineEditorTemplateRef(a) {
            this.b0 = a;
            this.e("InlineEditorTemplateRef");
        }
        get errorTemplateRef() {
            return this.bs;
        }
        set errorTemplateRef(a) {
            this.bs = a;
            this.e("ErrorTemplateRef");
        }
        get filterCellTemplateRef() {
            return this.bu;
        }
        set filterCellTemplateRef(a) {
            this.bu = a;
            this.e("FilterCellTemplateRef");
        }
        get visibleWhenCollapsed() {
            return this.ae;
        }
        set visibleWhenCollapsed(a) {
            this.ae = a;
            this.e("VisibleWhenCollapsed");
        }
        get pipeArgs() {
            return this.f;
        }
        set pipeArgs(a) {
            this.f = a;
            this.e("PipeArgs");
        }
        get collapsible() {
            return this.m;
        }
        set collapsible(a) {
            this.m = a;
            this.e("Collapsible");
        }
        get expanded() {
            return this.q;
        }
        set expanded(a) {
            this.q = a;
            this.e("Expanded");
        }
        get defaultWidth() {
            return this.br;
        }
        set defaultWidth(a) {
            this.br = a;
            this.e("DefaultWidth");
        }
        get widthSetByUser() {
            return this.af;
        }
        set widthSetByUser(a) {
            this.af = a;
            this.e("WidthSetByUser");
        }
        get parentColumn() {
            return this.bg;
        }
        set parentColumn(a) {
            this.bg = a;
            this.e("ParentColumn");
        }
        get formatterRef() {
            return this.bv;
        }
        set formatterRef(a) {
            this.bv = a;
            this.e("FormatterRef");
        }
        get summaryFormatterRef() {
            return this.b3;
        }
        set summaryFormatterRef(a) {
            this.b3 = a;
            this.e("SummaryFormatterRef");
        }
    }
    WebColumnDescription.$t = /*@__PURE__*/ markType(WebColumnDescription, 'WebColumnDescription', Description.$);
    return WebColumnDescription;
})();

==> igniteui-react-core-19.0.0.tgz: package/esm2015/lib/WebColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnDescription = /*@__PURE__*/ (() => {
    class WebColumnDescription extends Description {
        get_type() {
            return "WebColumn";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.bn = null;
            this.bq = null;
            this.b3 = null;
            this.ag = false;
            this.ae = false;
            this.y = false;
            this.v = false;
            this.w = false;
            this.ac = false;
            this.s = false;
            this.z = false;
            this.aa = false;
            this.af = false;
            this.t = false;
            this.u = false;
            this.b4 = null;
            this.bw = null;
            this.br = null;
            this.ba = null;
            this.bs = null;
            this.a9 = null;
            this.bi = null;
            this.bj = null;
            this.bp = null;
            this.b1 = null;
            this.x = false;
            this.ah = false;
            this.ad = false;
            this.bk = null;
            this.a2 = 0;
            this.a0 = 0;
            this.a3 = 0;
            this.a1 = 0;
            this.a8 = null;
            this.bx = null;
            this.ab = false;
            this.b0 = null;
            this.h = null;
            this.n = null;
            this.p = null;
            this.b2 = null;
            this.bh = null;
            this.bt = null;
            this.bv = null;
            this.bl = null;
            this.bo = null;
            this.ai = false;
            this.l = null;
            this.j = null;
            this.bb = null;
            this.by = null;
            this.bu = null;
            this.bm = null;
            this.b5 = null;
            this.bz = null;
        }
        get field() {
            return this.bn;
        }
        set field(a) {
            this.bn = a;
            this.g("Field");
        }
        get header() {
            return this.bq;
        }
        set header(a) {
            this.bq = a;
            this.g("Header");
        }
        get title() {
            return this.b3;
        }
        set title(a) {
            this.b3 = a;
            this.g("Title");
        }
        get sortable() {
            return this.ag;
        }
        set sortable(a) {
            this.ag = a;
            this.g("Sortable");
        }
        get selectable() {
            return this.ae;
        }
        set selectable(a) {
            this.ae = a;
            this.g("Selectable");
        }
        get groupable() {
            return this.y;
        }
        set groupable(a) {
            this.y = a;
            this.g("Groupable");
        }
        get editable() {
            return this.v;
        }
        set editable(a) {
            this.v = a;
            this.g("Editable");
        }
        get filterable() {
            return this.w;
        }
        set filterable(a) {
            this.w = a;
            this.g("Filterable");
        }
        get resizable() {
            return this.ac;
        }
        set resizable(a) {
            this.ac = a;
            this.g("Resizable");
        }
        get autosizeHeader() {
            return this.s;
        }
        set autosizeHeader(a) {
            this.s = a;
            this.g("AutosizeHeader");
        }
        get hasSummary() {
            return this.z;
        }
        set hasSummary(a) {
            this.z = a;
            this.g("HasSummary");
        }
        get hidden() {
            return this.aa;
        }
        set hidden(a) {
            this.aa = a;
            this.g("Hidden");
        }
        get selected() {
            return this.af;
        }
        set selected(a) {
            this.af = a;
            this.g("Selected");
        }
        get disableHiding() {
            return this.t;
        }
        set disableHiding(a) {
            this.t = a;
            this.g("DisableHiding");
        }
        get disablePinning() {
            return this.u;
        }
        set disablePinning(a) {
            this.u = a;
            this.g("DisablePinning");
        }
        get width() {
            return this.b4;
        }
        set width(a) {
            this.b4 = a;
            this.g("Width");
        }
        get maxWidth() {
            return this.bw;
        }
        set maxWidth(a) {
            this.bw = a;
            this.g("MaxWidth");
        }
        get headerClasses() {
            return this.br;
        }
        set headerClasses(a) {
            this.br = a;
            this.g("HeaderClasses");
        }
        get headerStyles() {
            return this.ba;
        }
        set headerStyles(a) {
            this.ba = a;
            this.g("HeaderStyles");
        }
        get headerGroupClasses() {
            return this.bs;
        }
        set headerGroupClasses(a) {
            this.bs = a;
            this.g("HeaderGroupClasses");
        }
        get headerGroupStyles() {
            return this.a9;
        }
        set headerGroupStyles(a) {
            this.a9 = a;
            this.g("HeaderGroupStyles");
        }
        get cellClassesRef() {
            return this.bi;
        }
        set cellClassesRef(a) {
            this.bi = a;
            this.g("CellClassesRef");
        }
        get cellStylesRef() {
            return this.bj;
        }
        set cellStylesRef(a) {
            this.bj = a;
            this.g("CellStylesRef");
        }
        get formatterRef() {
            return this.bp;
        }
        set formatterRef(a) {
            this.bp = a;
            this.g("FormatterRef");
        }
        get summaryFormatterRef() {
            return this.b1;
        }
        set summaryFormatterRef(a) {
            this.b1 = a;
            this.g("SummaryFormatterRef");
        }
        get filteringIgnoreCase() {
            return this.x;
        }
        set filteringIgnoreCase(a) {
            this.x = a;
            this.g("FilteringIgnoreCase");
        }
        get sortingIgnoreCase() {
            return this.ah;
        }
        set sortingIgnoreCase(a) {
            this.ah = a;
            this.g("SortingIgnoreCase");
        }
        get searchable() {
            return this.ad;
        }
        set searchable(a) {
            this.ad = a;
            this.g("Searchable");
        }
        get dataType() {
            return this.bk;
        }
        set dataType(a) {
            this.bk = a;
            this.g("DataType");
        }
        get rowEnd() {
            return this.a2;
        }
        set rowEnd(a) {
            this.a2 = a;
            this.g("RowEnd");
        }
        get colEnd() {
            return this.a0;
        }
        set colEnd(a) {
            this.a0 = a;
            this.g("ColEnd");
        }
        get rowStart() {
            return this.a3;
        }
        set rowStart(a) {
            this.a3 = a;
            this.g("RowStart");
        }
        get colStart() {
            return this.a1;
        }
        set colStart(a) {
            this.a1 = a;
            this.g("ColStart");
        }
        get additionalTemplateContext() {
            return this.a8;
        }
        set additionalTemplateContext(a) {
            this.a8 = a;
            this.g("AdditionalTemplateContext");
        }
        get minWidth() {
            return this.bx;
        }
        set minWidth(a) {
            this.bx = a;
            this.g("MinWidth");
        }
        get pinned() {
            return this.ab;
        }
        set pinned(a) {
            this.ab = a;
            this.g("Pinned");
        }
        get summariesRef() {
            return this.b0;
        }
        set summariesRef(a) {
            this.b0 = a;
            this.g("SummariesRef");
        }
        get disabledSummaries() {
            return this.h;
        }
        set disabledSummaries(a) {
            this.h = a;
            this.g("DisabledSummaries");
        }
        get filters() {
            return this.n;
        }
        set filters(a) {
            this.n = a;
            this.g("Filters");
        }
        get sortStrategy() {
            return this.p;
        }
        set sortStrategy(a) {
            this.p = a;
            this.g("SortStrategy");
        }
        get summaryTemplateRef() {
            return this.b2;
        }
        set summaryTemplateRef(a) {
            this.b2 = a;
            this.g("SummaryTemplateRef");
        }
        get bodyTemplateRef() {
            return this.bh;
        }
        set bodyTemplateRef(a) {
            this.bh = a;
            this.g("BodyTemplateRef");
        }
        get headerTemplateRef() {
            return this.bt;
        }
        set headerTemplateRef(a) {
            this.bt = a;
            this.g("HeaderTemplateRef");
        }
        get inlineEditorTemplateRef() {
            return this.bv;
        }
        set inlineEditorTemplateRef(a) {
            this.bv = a;
            this.g("InlineEditorTemplateRef");
        }
        get errorTemplateRef() {
            return this.bl;
        }
        set errorTemplateRef(a) {
            this.bl = a;
            this.g("ErrorTemplateRef");
        }
        get filterCellTemplateRef() {
            return this.bo;
        }
        set filterCellTemplateRef(a) {
            this.bo = a;
            this.g("FilterCellTemplateRef");
        }
        get visibleWhenCollapsed() {
            return this.ai;
        }
        set visibleWhenCollapsed(a) {
            this.ai = a;
            this.g("VisibleWhenCollapsed");
        }
        get pipeArgs() {
            return this.l;
        }
        set pipeArgs(a) {
            this.l = a;
            this.g("PipeArgs");
        }
        get editorOptions() {
            return this.j;
        }
        set editorOptions(a) {
            this.j = a;
            this.g("EditorOptions");
        }
        get parentColumn() {
            return this.bb;
        }
        set parentColumn(a) {
            this.bb = a;
            this.g("ParentColumn");
        }
        get name() {
            return this.by;
        }
        set name(a) {
            this.by = a;
            this.g("Name");
        }
        get hiddenChangeRef() {
            return this.bu;
        }
        set hiddenChangeRef(a) {
            this.bu = a;
            this.g("HiddenChangeRef");
        }
        get expandedChangeRef() {
            return this.bm;
        }
        set expandedChangeRef(a) {
            this.bm = a;
            this.g("ExpandedChangeRef");
        }
        get widthChangeRef() {
            return this.b5;
        }
        set widthChangeRef(a) {
            this.b5 = a;
            this.g("WidthChangeRef");
        }
        get pinnedChangeRef() {
            return this.bz;
        }
        set pinnedChangeRef(a) {
            this.bz = a;
            this.g("PinnedChangeRef");
        }
    }
    WebColumnDescription.$t = /*@__PURE__*/ markType(WebColumnDescription, 'WebColumnDescription', Description.$);
    WebColumnDescription.__canMarshalByValue = true;
    WebColumnDescription.__marshalByValueAlias = "Column";
    return WebColumnDescription;
})();
